{% extends "access_django_user_admin/base_nav_none.html" %}

{% load static %}

{% load get_settings %}

{% block title %}Sorry{% endblock %}

{% block content %}

<div class="row">
    <div class="col-sm-6 col-sm-offset-3">
        <div class="panel panel-info">

            <div class="panel-body" style="text-align: center;"> 
                        <p class="lead">Sorry!</p>
                        <p>You are not authorized to access this part of the site. <a class="btn btn-sm btn-warning" href="{{ back_url }}"
                                    role="button">Back</a></p>
            </div><!-- panel-body -->
        </div><!-- panel -->
    </div><!-- col -->
</div><!-- row -->
{% endblock %}
